﻿/*
  Examples below, demonstrating XSD 1.1 validation using two input files.
  The response types are XML and JSON.
*/
using System;
using System.IO;
using System.Net.Http;

namespace xsValidatorHttpRequest
{
    class XSValidator
    {
        static void Main(string[] args)
        {
            try
            {
                var httpClient = new HttpClient();
                var formInpDataContent = new MultipartFormDataContent();
                formInpDataContent.Add(new StreamContent(File.Open("../resources/two_inp_files/x1_valid_1.xml", FileMode.Open)), "xmlFile", "x1_valid_1.xml");
                formInpDataContent.Add(new StreamContent(File.Open("../resources/two_inp_files/x1.xsd", FileMode.Open)), "xsdFile1", "x1.xsd");

                byte[] xsdVerBytesVal = System.Text.Encoding.ASCII.GetBytes("1.1");
                formInpDataContent.Add(new ByteArrayContent(xsdVerBytesVal), "ver");

                byte[] xsd11CtaFullXPathBytesVal = System.Text.Encoding.ASCII.GetBytes("no");
                formInpDataContent.Add(new ByteArrayContent(xsd11CtaFullXPathBytesVal), "xsd11CtaFullXPath");

                byte[] responseTypeBytesVal = System.Text.Encoding.ASCII.GetBytes("xml");
                formInpDataContent.Add(new ByteArrayContent(responseTypeBytesVal), "responseType");

                var httpResponse = httpClient.PostAsync("https://www.softwarebytes.org/xmlvalidation/api/xsValidationHandler", formInpDataContent).Result;
                string httpResponseStrVal = httpResponse.Content.ReadAsStringAsync().Result;
                
                Console.WriteLine("\nExample 1 output:\n");
                Console.WriteLine(httpResponseStrVal);
                formInpDataContent.Dispose();

                formInpDataContent = new MultipartFormDataContent();
                formInpDataContent.Add(new StreamContent(File.Open("../resources/two_inp_files/x1_invalid_1.xml", FileMode.Open)), "xmlFile", "x1_invalid_1.xml");
                formInpDataContent.Add(new StreamContent(File.Open("../resources/two_inp_files/x1.xsd", FileMode.Open)), "xsdFile1", "x1.xsd");                
                formInpDataContent.Add(new ByteArrayContent(xsdVerBytesVal), "ver");                
                formInpDataContent.Add(new ByteArrayContent(xsd11CtaFullXPathBytesVal), "xsd11CtaFullXPath");
                responseTypeBytesVal = System.Text.Encoding.ASCII.GetBytes("json");
                formInpDataContent.Add(new ByteArrayContent(responseTypeBytesVal), "responseType");

                httpResponse = httpClient.PostAsync("https://www.softwarebytes.org/xmlvalidation/api/xsValidationHandler", formInpDataContent).Result;
                httpResponseStrVal = httpResponse.Content.ReadAsStringAsync().Result;

                Console.WriteLine("\nExample 2 output:\n");
                Console.WriteLine(httpResponseStrVal);
                formInpDataContent.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine("An exception has occured:");
                Console.WriteLine(ex.Message);
            }
        }
    }
}
